@@ -1,6 +1,7 @@
 import math
 import json
 import requests
+from adsb_tools.utils import requests_utils
 
 EARTH_RADIUS_KM = 6371.0
 
@@ -120,3 +121,25 @@ def get_aircraft(base_url, filter_aircraft = True):
         ]
 
     return result
+
+
+def get_hex_db_flight(icao_24):
+    """
+    Get values from HexDB
+    """
+    hex_db_url = f'https://hexdb.io/api/v1/aircraft/{icao_24}'
+    hex_db_result = requests_utils.call_url(hex_db_url)
+    hex_db_obj = json.loads(hex_db_result.content)
+
+    return hex_db_obj
+
+
+def get_adsb_db_flight(icao_24):
+    """
+    Get values from ADSB DB
+    """
+    adsb_db_url = f'https://api.adsbdb.com/v0/aircraft/{icao_24}'
+    adsb_db_result = requests_utils.call_url(adsb_db_url)
+    adsb_db_obj = json.loads(adsb_db_result.content)
+
+    return adsb_db_obj
